@@ -120,6 +120,14 @@ def csv_to_html_table(fname,headers=None,delimiter=","):
     table+="</table><br>"
     return table
 
+class MultiprocessDomparserResult():
+    def __init__(self, run_pool):
+        self.run_pool = run_pool
+
+    def html(self):
+        html_outputs = self.run_pool(lambda out: out.html())
+        return html_outputs
+
 class DomparserResult():
     def __init__(self, html_content, output_pdfs, output_pngs, file_map):
         self.html_conent = html_content
@@ -144,10 +152,10 @@ class DomparserResult():
 
     def show(self):
         display = importlib.import_module("IPython.core.display")
-        display.display(display.HTML(self._replace_all_links("\n".join(self.html_conent))))
+        display.display(display.HTML(self.html()))
 
     def html(self):
-        return self.html_conent
+        return self._replace_all_links("\n".join(self.html_conent))
 
     def output_chart_html(self, index=0):
         self.output_pngs[index].seek(0)
@@ -470,11 +478,13 @@ class Eniam():
 
     def dom(self, input, silent=True):
         if isinstance(input, list):
-            pool = Pool()
-            opts = {
-                'silent': silent,
-            }
-            return pool.map(self._exec_dom_opt, map(lambda sentence: [sentence, opts], input))
+            def run_pool(mapper):
+                pool = Pool()
+                opts = {
+                    'silent': silent,
+                }
+                return pool.map(lambda opts: mapper(self._exec_dom_opt(opts)), map(lambda sentence: [sentence, opts], input))
+            return MultiprocessDomparserResult(run_pool)
         else:
             return self._exec_dom(input, silent)
 
